/* eslint-disable */
// This base model was auto-generated by export_app
// PLEASE DO NOT EDIT
// you can make changes in app/models/{{application_name}}/{{model_name}}.js
// or regenerate this file by running
// `./manage.py export{%if target_app %} --target_app {{target_app}}{% endif %} {{endpoint}}`
{% if base %}
  import Model from '../../{{base.1}}/{{base.0}}';
{% else %}
  import Model from 'ember-data/model';
{% endif %}
{% if fields|length > 0 %}
import attr from 'ember-data/attr';
{% endif %}
{% if rels|length > 0 %}
import { {% if belongsTo and hasMany %}belongsTo, hasMany{% else %}{%if belongsTo %}belongsTo{% else %}hasMany{% endif %}{% endif %} } from 'ember-data/relationships';
{% endif %}

export default Model.extend({
  {% for field in fields %}
    {{field.name}}: attr({% if field.type %}'{{field.type}}'{% endif %}),
  {% endfor %}
  {% for field in rels %}
    {{field.name}}: {{field.type}}('{%if target_app %}{{target_app}}{% else %}{{field.app}}{% endif %}/{{field.related_model}}', {
      async: true,
      inverse: {%if field.inverse %}'{{field.inverse}}'{% else %}null{% endif %},
    }),
  {% endfor %}
});
